@@ -20,13 +20,15 @@ class Account:
         account = AccountModel(
             name=request.name,
             user_id=app.current_user_id,
+            platform_id=app.current_platform_id,
         )
         await account.async_save()
         return Response(content=account.to_dict(), status_code=201)
 
     @staticmethod
     async def update(
-        account: AccountModel, request: AccountUpdateRequest
+        account: AccountModel,
+        request: AccountUpdateRequest,
     ) -> Response:
         account.name = request.name
         await account.async_save()
